% Demosaicking using the frequency domain method for the stripe CFA
% pattern
% Eric Dubois 2007-05-24
%       [RGB] = demos_freq_stripe(CFA)
%       CFA(:,:)   input stripe CFA mosaicked image, double according to the
%       pattern       
%        R B G R B G
%        G R B G R B
%        B G R B G R
%       RGB(:,:,3) output RGB image, double
function [RGB] = demos_freq_stripe(CFA)
%load the filters
load demos_adapt_filters_LS_stripe11
%Use the filters to demosaic the CFA image
S = size(CFA);
N1 = S(1); N2 = S(2);
yc = 0:N1-1; xc = 0:N2-1;
[XC,YC] = meshgrid(xc,yc);
%Filter the CFA image with h2R and h2I
r2R = imfilter(CFA,h2R,'replicate','same');
r2I = imfilter(CFA,h2I,'replicate','same');
%Create the estimated q1', q2', q3'
sq3 = sqrt(3);
%The modulation frequency sinusoidal signals
C2 = cos(2*pi*(XC-YC)/3);
S2 = sin(2*pi*(XC-YC)/3);
q1p = CFA - 2*r2R;
q2p = r2R.*C2 + r2I.*S2;
q3p = r2R.*S2 - r2I.*C2;
%The demosaicked image
%Red channel
RGB(:,:,1) = q1p + 2*q2p;
%Green channel
RGB(:,:,2) = q1p - q2p - sq3*q3p;
%Blue channel
RGB(:,:,3) = q1p - q2p + sq3*q3p;